@@ -1,48 +1,49 @@
-#' Add Miscellaneous Web Map Elements
+#' Add Elements to Web Map
 #'
-#' These functions can be used to augment a \href{http://leafletjs.com/}{Leaflet} web map with additional elements.
+#' Augment a \href{http://leafletjs.com/}{Leaflet} web map with additional elements.
 #' The \code{AddHomeButton} function adds a button that zooms to the initial map extent.
 #' The \code{AddClusterButton} function adds a button that toggles marker clusters on and off.
-#' The \code{AddSearchButton} function adds a search element that may be used to locate, and move to, a marker.
+#' The \code{AddSearchButton} function adds a control that may be used to search markers/features location by property.
 #' And the \code{AddCircleLegend} function adds a map legend.
 #'
 #' @param map '\link[leaflet]{leaflet}'.
 #'   Map widget object
-#' @param extent 'Spatial*', 'Raster*', 'Extent', 'matrix', or 'numeric'.
+#' @param extent 'Spatial*', 'Raster*', 'Extent', 'matrix', or 'numeric' vector.
 #'   Extent object (or object from which an \code{\link[raster]{extent}} object can be extracted/created)
 #'   representing a rectangular geographical area on the map.
 #'   The extent must be specified in the coordinate reference system (CRS) of the web map,
 #'   usually in latitude and longitude using WGS 84 (also known as \href{https://epsg.io/4326}{EPSG:4326}).
 #'   By default, the extent object is read from the map widget.
-#' @param position 'character'.
+#' @param position 'character' string.
 #'   Position of the button on the web map.
 #'   Possible values are \code{"topleft"}, \code{"topright"}, \code{"bottomleft"}, and \code{"bottomright"}.
-#' @param clusterId 'character'.
+#' @param clusterId 'character' string.
 #'   Identification for the marker cluster layer.
-#' @param group 'character'.
+#' @param group 'character' string.
 #'   Name of the group whose features will be searched.
-#' @param propertyName 'character'.
+#' @param propertyName 'character' string.
 #'   Property name used to describe markers, such as, \code{"label"} and \code{"popup"}.
-#' @param zoom 'integer'.
+#' @param zoom 'integer' count.
 #'   Zoom level for move to location after marker found in search.
-#' @param textPlaceholder 'character'.
-#'   Text message to show in search element.
-#' @param openPopup 'logical'.
+#' @param textPlaceholder 'character' string.
+#'   Message to show in search element.
+#' @param openPopup 'logical' flag.
 #'   Whether to open the marker popup associated with the searched for marker.
-#' @param labels 'character'.
-#'   Vector of text labels in the legend.
-#' @param colors 'character'.
-#'   Vector of (HTML) colors corresponding to \code{labels}.
-#' @param radius 'numeric'.
+#' @param labels 'character' vector.
+#'   Labels in the legend.
+#' @param colors 'character' vector.
+#'   HTML colors corresponding to \code{labels}.
+#' @param radius 'numeric' number.
 #'   Border radius of symbols in the legend, in pixels.
-#' @param opacity 'numeric'.
+#' @param opacity 'numeric' number.
 #'   Opacity of symbols in the legend, from 0 to 1.
-#' @param symbol 'character'.
+#' @param symbol 'character' string.
 #'   Symbol type in the legend, either \code{"square"} or \code{"circle"}.
-#' @param title 'character'.
+#' @param title 'character' string.
 #'   Legend title
 #'
-#' @return Used for the side-effect of a button placed on a web map.
+#' @return Returns an object of class 'leaflet'.
+#'   A new \code{map} object with added element.
 #'
 #' @author J.C. Fisher, U.S. Geological Survey, Idaho Water Science Center
 #'
@@ -66,7 +67,7 @@
 #'
 #' labels <- c("Non-capital", "Capital")
 #' colors <- c("green", "red")
-#' fillColor <- colors[(city@data$capital > 0) + 1L]
+#' fillColor <- colors[(city@data$capital > 0) + 1]
 #' map <- CreateWebMap("Topo")
 #' map <- leaflet::addCircleMarkers(map, radius = 6, color = "white", weight = 1,
 #'                                  opacity = 1, fillColor = fillColor, fillOpacity = 1,
@@ -159,33 +160,49 @@ AddSearchButton <- function(map, group, propertyName="label", zoom=NULL,
 
   # check arguments
   checkmate::assertClass(map, c("leaflet", "htmlwidget"))
-  checkmate::assertCharacter(group, min.chars=1, any.missing=FALSE, min.len=1)
+  checkmate::assertString(group, min.chars=1)
   checkmate::assertString(propertyName, min.chars=1)
   checkmate::assertInt(zoom, lower=0, null.ok=TRUE)
   checkmate::assertString(textPlaceholder, null.ok=TRUE)
   checkmate::assertFlag(openPopup)
   checkmate::assertChoice(position, c("topleft", "topright", "bottomleft", "bottomright"))
 
-  map$dependencies <- c(map$dependencies, .SearchDependencies())
-  leaflet::invokeMethod(map,
-                        data=leaflet::getMapData(map),
-                        method="addSearchMarker",
-                        group,
-                        position,
-                        propertyName,
-                        zoom,
-                        textPlaceholder,
-                        openPopup)
+  # check group is in map widget
+  grp <- unlist(lapply(lapply(map$x$calls, function(x) x[[2]]), function(x) x[5][[1]]))
+  if (!(group %in% grp)) stop("Group with name '", group, "' missing from map widget.")
+
+  # attach html dependencies to map widget
+  map$dependencies <- c(map$dependencies, .GetLeafletSearchDependencies())
+
+  # define arguments to be passed to the javascript method
+  circle <- list("radius"               = 20,
+                 "weight"               = 3,
+                 "opacity"              = 0.7,
+                 "color"                = "#FF4040",
+                 "stroke"               = TRUE,
+                 "fill"                 = FALSE)
+  marker <- list("icon"                 = FALSE,
+                 "animate"              = TRUE,
+                 "circle"               = circle)
+  option <- list("propertyName"         = propertyName,
+                 "zoom"                 = zoom,
+                 "textPlaceholder"      = textPlaceholder,
+                 "openPopup"            = openPopup,
+                 "position"             = position,
+                 "initial"              = FALSE,
+                 "hideMarkerOnCollapse" = TRUE,
+                 "marker"               = marker)
+
+  # add leaflet-search plugin to map
+  leaflet::invokeMethod(map, leaflet::getMapData(map), "addSearchControl",
+                        group, leaflet::filterNULL(option))
 }
 
-.SearchDependencies <- function() {
-  list(htmltools::htmlDependency(name="leaflet-search",
-                                 version="2.8.0",
-                                 src=system.file("htmlwidgets/plugins/leaflet-search", 
-                                                 package="inlmisc"),
-                                 script=c("leaflet-search.min.js", 
-                                          "leaflet-search-binding.js"),
-                                 stylesheet="leaflet-search.min.css"))
+
+.GetLeafletSearchDependencies <- function() {
+  list(htmltools::htmlDependency("leaflet-search", "2.9.6", "htmlwidgets/plugins/leaflet-search",
+                                 script=c("leaflet-search.min.js", "leaflet-search-binding.js"),
+                                 stylesheet="leaflet-search.min.css", package="inlmisc"))
 }
 
 
@@ -201,11 +218,10 @@ AddLegend <- function(map, labels, colors, radius, opacity=0.5, symbol=c("square
   checkmate::assertCharacter(colors, any.missing=FALSE, len=length(labels))
   checkmate::assertNumeric(radius, lower=0, any.missing=FALSE, min.len=1)
   checkmate::assertNumber(opacity, lower=0, upper=1, finite=TRUE)
+  symbol <- match.arg(symbol)
   checkmate::assertString(title, null.ok=TRUE)
   checkmate::assertChoice(position, c("topleft", "topright", "bottomleft", "bottomright"))
 
-  symbol <- match.arg(symbol)
-
   sizes <- rep(radius, length.out=length(colors)) * 2
   if (symbol == "square")
     fmt <- "%s; width:%fpx; height:%fpx; margin-top:4px;"
@@ -214,8 +230,8 @@ AddLegend <- function(map, labels, colors, radius, opacity=0.5, symbol=c("square
   col <- sprintf(fmt, colors, sizes, sizes)
   fmt <- "<div style='display:inline-block; height:%fpx; line-height:%fpx; margin-top:4px;'>%s</div>"
   lab <- sprintf(fmt, sizes, sizes, labels)
-  if (!is.null(title))
+  if (is.character(title))
     title <- sprintf("<div style='text-align:center;'>%s</div>", title)
-  return(leaflet::addLegend(map, position=position, colors=col, labels=lab,
-                            labFormat=as.character(), opacity=opacity, title=title))
+  leaflet::addLegend(map, position=position, colors=col, labels=lab,
+                     labFormat=as.character(), opacity=opacity, title=title)
 }
